betty.load module - Betty 0.4.0a1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.load module

Provide the Ancestry loading API.

class betty.load.Loader

  Bases: `object`

  Load (part of) the project’s ancestry.

  Extensions may subclass this to add data to the ancestry, if they choose to do so.

  async load() → None

    Load ancestry data.

    Return type:

      `None`

class betty.load.PostLoader

  Bases: `object`

  Act on the project’s ancestry having been loaded.

  async post_load() → None

    Act on the ancestry having been loaded.

    This method is called immediately after `betty.load.Loader.load()`.

    Return type:

      `None`

async betty.load.load(app: betty.app.App) → None

  Load an ancestry.

  Parameters:

    app (`betty.app.App`)

  Return type:

    `None`